#ifndef DISPATCHER_H
#define DISPATCHER_H

#include <QString>
#include <QUrl>
#include <QProcess>

#include "playlistparser.h"
#include "playlistloop.h"
#include "runnable.h"
#include "ui/viewer.h"
#include "remote.h"
#include "settings.h"
#include "cleanser.h"


class CommandLineParser;
class Dispatcher : public QObject
{
    Q_OBJECT

public:
    Dispatcher(Viewer *viewer, CommandLineParser const* cmdparse);
    ~Dispatcher(void);

    void startRemote();

public slots:
    void next(void);
    void shootScreen(void);
    void finalize(void);
    void endIdle(void);
    void startInlineRemote(void);
    bool isValid(void) const { return m_is_valid; }

private:
    enum Status {
        StatusNone = 0,
        StatusBrowser,
        StatusAfterBrowser,
        StatusPlaylist
    };

    Settings *settings;
    Cleanser *cleanser;
    Dispatcher::Status m_status;
    Runnable *m_currentWidget;
    Runnable *m_prevWidget;
    QString m_mode;
    Viewer *m_viewer;
    QDateTime m_lastUpdate;
    Remote * remote;
    bool m_plRefresh;
    QTimer m_plTimer;

    PlaylistParser *m_pl;
    PlaylistLoop *m_loop;
    int m_loopIdx;

    bool m_idling;
    bool m_is_valid;

    QString remotePid;

    QTimer m_ssTimer;

private:
    void disableScreensaver();

    void StartSession();
    void StopSession();
    void AddTime(int seconds);

    void startup();
    void reconnectMouseEvent();
    void afterBrowser();
    void startBrowser(QUrl url = QUrl());
    void execHook(QString hook);
    QDateTime getLastEdit();

    void view_next();

private slots:
    void onReconnectMouseEventTimeout();
    void onScreensaverTimeout();
    void onMouseEvent();
    void showLoopNext();
    void onPlTimeout();
    void startSlideshow();
    void goTo(int index, int loop);
    void goTo(QString);
    void startNoScreensaver(int, QProcess::ExitStatus);
};

#endif
