#ifndef PLAYLISTLOOP_H
#define PLAYLISTLOOP_H

#include <QDateTime>
#include <QDate>
#include <QTime>
#include <QBitArray>

#include "playlistitem.h"

class PlaylistLoop
{
public:
    PlaylistLoop(int default_time, QDomNode &node, QString baseUrl);
    PlaylistLoop(int default_time, QString &data, QString baseUrl);
    ~PlaylistLoop();

    int count() const { return m_items.count(); }
    void refresh();
    PlaylistItem * at(int i) { return m_items.at(i); }
    bool isEmpty() const { return m_id.isEmpty(); }
    bool downloadable() const { return m_downloadable; }
    QString id() const { return m_id; }
    int priority() const { return m_priority; }
    bool nowOk() const;
    QString baseUrl() const { return m_baseUrl; }
    QList<PlaylistItem *> items() const { return m_items; }

private:
    QString m_baseUrl;
    QString m_id;
    bool m_idle;
    QString m_startTimeStr;
    QString m_endTimeStr;
    QTime m_startTime;
    QTime m_endTime;
    QString m_weekdaysStr;
    QBitArray m_weekdays;
    QDate m_startDate;
    QDate m_endDate;
    QString m_startDateStr;
    QString m_endDateStr;
    int m_priority;
    bool m_downloadable;
    int m_default_time;

    QList<PlaylistItem *> m_items;

    int m_curIdx;

    // For local playlist.
    void fromString(QString &data);

    // For server playlist.
    void fromXmlNode(QDomNode &node);
    void childFromXmlNode(QDomNode &node);

    bool addDirectoryInItems(QString const& path, int time);

    bool validate();
    bool validateDate();
    bool validateTime();
    bool validateWeekdays();

    void addDemoItems();
};

#endif
