#include <QPixmap>
#include <QRect>
#include <QPalette>
#include <QDesktopWidget>
#include <settings.h>
#include <QMouseEvent>

#include "image.h"

Image::Image(PlaylistItem *item, QWidget *parent)
    : QLabel(parent)
    , Runnable(item->time())
{
    m_uri = item->uri();
    setAlignment(Qt::AlignCenter);
    setBlackBackground();
    buildPixmap();
}


void Image::setBlackBackground(void)
{
    QPalette p;
    p.setColor(QPalette::Background, Qt::black);
    QLabel::setAutoFillBackground(true);
    QLabel::setPalette(p);
}


void Image::buildPixmap(void)
{
    QPixmap pixmap;
    int p_w, p_h, s_w, s_h;

    QString path = m_uri.mid(7);
    QPixmap source(path);
    if (source.isNull())
    {
        setPixmap(source);
        return;
    }

    QRect g = qobject_cast<QWidget *>(QLabel::parent())->geometry();
    p_w = g.width();
    p_h = g.height();
    s_w = source.width();
    s_h = source.height();

    qDebug()<<p_w<<p_h<<s_w<<s_h;
    Settings  *settings = Settings::load();
    if(settings->get("slideshow/resize").toBool()){
        pixmap = source.scaled(p_w,p_h,Qt::KeepAspectRatio, Qt::SmoothTransformation);
    }
    else if ((s_w <= p_w) && (s_h <= p_h)){
        pixmap = source;
    }
    else{
        pixmap = source.scaled(p_w,p_h,Qt::KeepAspectRatio, Qt::SmoothTransformation);
    }
    setPixmap(pixmap);
}


bool Image::startImpl(void)
{
    if (pixmap()->isNull())
    {
        emit(end());
        return false;
    }
    return true;
}


bool Image::stopImpl(void) { return true; }


bool Image::onTimeoutImpl(void)
{ emit(end()); return true; }


void Image::pauseImpl(void) {}


void Image::resumeImpl(void) {}


void Image::mousePressEvent(QMouseEvent* event)
{
    if (event->button() == Qt::RightButton)
        emit rightclick();
}
