#include "runnable.h"


RunnableTimer::RunnableTimer(Runnable *run, QObject* parent)
    : QTimer(parent), m_run(run)
{
    QObject::connect(this, SIGNAL(timeout()),
                     this, SLOT(onTimeout()));
}


void RunnableTimer::onTimeout(void)
{
    qDebug() << "Timeout";
    if (!m_run->onTimeoutImpl() || !m_run->isActive()) return;
    m_run->stop();
}


Runnable::Runnable(int time)
    : m_timer(this)
    , m_time(time) {}


void Runnable::restart(bool force_stop)
{
    if (force_stop && isActive()) stop();
    start();
}


void Runnable::start(void)
{
    qDebug() << "Starting" << this;
    if (!startImpl()) return;
    if (m_time > 0 && !m_timer.isActive())
        m_timer.start(m_time * 1000);
    m_started = true;
}


bool Runnable::pause(void)
{
    if (isActive())
    {
        qDebug() << "Pause";
        if (m_time > 0) m_timer.stop();
        pauseImpl();
        return true;
    }
    else
    {
        qDebug() << "Resume";
        if (m_time > 0) m_timer.start();
        resumeImpl();
        return false;
    }
}


void Runnable::stop(void)
{
    qDebug() << "Stopping" << this;
    if (!stopImpl() || !m_timer.isActive()) return;
    m_timer.stop();
    m_started = false;
}


bool Runnable::isActive(void)
{ return m_timer.isActive() || (m_time < 1 && m_started); }


void Runnable::setTimeout(int time)
{ m_time = time; }
