#include <QDebug>
#include <QAction>

#include "cookiesaver.h"

CookieSaver::CookieSaver(QStringList *urls, QWidget *parent)
    : QDialog(parent)
    , m_urls(urls)
    , m_idx(0)
{
    QAction *action;

    if (m_urls->count() > 1)
    {
        action = m_navBar.addAction(QIcon::fromTheme("previous"), "Previous");
        connect(action, SIGNAL(triggered()), this, SLOT(onPrevious()));
        action = m_navBar.addAction(QIcon::fromTheme("next"), "Next");
        connect(action, SIGNAL(triggered()), this, SLOT(onNext()));
    }
    m_navBar.addWidget(&m_addressEdit);

    m_webView.page()->networkAccessManager()->setCookieJar(&m_jar);

    m_buttonBox.setOrientation(Qt::Horizontal);
    m_buttonBox.setStandardButtons(QDialogButtonBox::Cancel|QDialogButtonBox::Ok);
    connect(&m_buttonBox, SIGNAL(accepted()), this, SLOT(accept()));
    connect(&m_buttonBox, SIGNAL(rejected()), this, SLOT(reject()));

    m_layout.addWidget(&m_navBar);
    m_layout.addWidget(&m_webView);
    m_layout.addWidget(&m_buttonBox);

    setLayout(&m_layout);

    show();
}

void CookieSaver::show()
{
    QString url = m_urls->at(m_idx);
    m_addressEdit.setText(url);
    m_webView.load(QUrl(url));
}

void CookieSaver::onPrevious()
{
    --m_idx;
    if (m_idx < 0)
        m_idx = m_urls->count() - 1;
    show();
}

void CookieSaver::onNext()
{
    ++m_idx;
    if (m_idx >= m_urls->count())
        m_idx = 0;
    show();
}

QList<QNetworkCookie> CookieSaver::allCookies()
{
    FakeCookieJar *jar = qobject_cast<FakeCookieJar *>(
            m_webView.page()->networkAccessManager()->cookieJar());
    return jar->allCookies();
}
